<?php

namespace Pinpoint\PackingSlips\Model\Config\Source;

use Magento\Framework\DB\Ddl\Table;

class Options extends \Magento\Eav\Model\Entity\Attribute\Source\AbstractSource
{
    /**
     * @var array $options
     */
    protected $options = [];

    /**
     * Get Options
     *
     * @return array
     */
    public function getAllOptions()
    {
        if (!$this->options) {
            $this->options = [
                ['value' => 'B1 - R1', 'label' => 'B1 - R1'],
                ['value' => 'B2 - R2', 'label' => 'B2 - R2'],
                ['value' => 'B3 - R3', 'label' => 'B3 - R3'],
                ['value' => 'B4 - R4', 'label' => 'B4 - R4'],
                ['value' => 'B5 - TF1', 'label' => 'B5 - TF1'],
                ['value' => 'B6 - F1', 'label' => 'B6 - F1'],
                ['value' => 'B7 - F2', 'label' => 'B7 - F2'],
                ['value' => 'B8 - EF1', 'label' => 'B8 - EF1'],
                ['value' => 'B9 - Z1', 'label' => 'B9 - Z1'],
                ['value' => 'B10 - EF2', 'label' => 'B10 - EF2'],
                ['value' => 'B11 - FC1', 'label' => 'B11 - FC1'],
                ['value' => 'B12 - RP1', 'label' => 'B12 - RP1']
            ];
        }

        return $this->options;
    }

    /**
     * Get a text for option value
     *
     * @param string|integer $value
     * @return string|bool
     */
    public function getOptionText($value)
    {
        foreach ($this->getAllOptions() as $option) {
            if ($option['value'] == $value) {
                return $option['label'];
            }
        }
        return false;
    }

    /**
     * Retrieve flat column definition
     *
     * @return array
     */
    public function getFlatColumns()
    {
        $attributeCode = $this->getAttribute()->getAttributeCode();
        return [
            $attributeCode => [
                'unsigned' => false,
                'default' => null,
                'extra' => null,
                'type' => Table::TYPE_TEXT,
                'nullable' => true,
                'comment' => 'Custom Attribute Options  ' . $attributeCode . ' column',
            ],
        ];
    }
}